From 52212305a5c223f0b51b3b8edd00d664c16d7cb2 Mon Sep 17 00:00:00 2001 From: Andrea Mazzoleni Date: Mon, 5 Oct 2015 23:03:03 +0200 Subject: [PATCH] Update HISTORY --- HISTORY | 9 +++++---- 1 file changed, 5 insertions(+), 4 deletions(-) diff --git a/HISTORY b/HISTORY index 1773139d..f4221f70 100644 --- a/HISTORY +++ b/HISTORY @@ -1,7 +1,7 @@ SnapRAID HISTORY ================ -9.0 2015/09 +9.0 2015/10 =========== * Fixes an invalid assumption that could happen when using the -e, --filter-error option with "fix" or "check". @@ -14,11 +14,12 @@ SnapRAID HISTORY parity during sync is really correct. The "status" command reports the amount of scrub necessary to ensure to scrub all the synced blocks. - * Reduced the RAM memory usage, expecially with big files. - For each block, it now uses 17 bytes, instead of 28 bytes - (for 32 bit) and 36 bytes (for 64 bit). * The -p, --percentage option supports the new the arguments: "bad", "sync" and "full" to define the kind of scrub to do. + * Drastically reduced the memory usage. For each block, it now + uses 17 bytes of memory, instead of the previous 28 bytes + (for 32 bit) or 36 bytes (for 64 bit). + This could result is a memory saving of up the 50%. * Extends the -h, --pre-hash option to also verify moved and copied files into the array before running a 'sync'. * Update 'best' RAID functions for recent Atom CPUs.